@@ -217,13 +217,17 @@ nonlinear_bins <- function(
   threshold_1 = 0.9,
   threshold_2 = 0.99
 ) {
-  # Validation checks using `cli` for robust error messaging:
+  # Validation checks using `cli` for robust error messaging: ----
   # Ensures the input data is a data frame or tibble.
-  if (!is.data.frame(data) && !tibble::is_tibble(data)) {
-    cli::cli_abort("The input data must be a data frame or tibble.")
-  }
+  validate_data_structure(
+    input = data,
+    structure_type = c("data.frame", "tbl", "tbl_df"),
+    logic = "or",
+    type = "error"
+  )
 
-  # Ensure Ps_col and outcome_col arguments are provided with tailored error messages
+  # Ensure Ps_col and outcome_col arguments are provided ----
+  # with tailored error messages
   if (missing(Ps_col) && missing(outcome_col)) {
     cli::cli_abort(
       "Both {.var Ps_col} and {.var outcome_col} arguments must be provided."
@@ -234,116 +238,126 @@ nonlinear_bins <- function(
     cli::cli_abort("The {.var outcome_col} argument must be provided.")
   }
 
-  # Check if Ps column is numeric
-
-  # dplyr::pull the Ps data
-  Ps_check <- data |> dplyr::pull({{ Ps_col }})
-
-  # check the Ps_check remains continuous
-  if (!is.numeric(Ps_check)) {
-    cli::cli_abort("The {.var Ps_col} must contain numeric values.")
-  }
+  # dplyr::pull the Ps data ----
+  Ps_check <- validate_data_pull(
+    input = data,
+    col = {{ Ps_col }},
+    var_name = "Ps_col",
+    calls = 5
+  )
 
+  # check the Ps_check remains continuous ----
   # Check if Ps column is continuous (values between 0 and 1)
-  if (any(Ps_check < 0 | Ps_check > 1, na.rm = TRUE)) {
-    cli::cli_abort(
-      "The probability of survival (Ps) values must be between 0 and 1."
-    )
-  }
+  validate_numeric(
+    input = Ps_check,
+    min = 0,
+    max = 1,
+    type = "error",
+    var_name = "Ps_col"
+  )
 
-  if (any(is.na(Ps_check))) {
-    cli::cli_warn(
-      "Missing values detected in {.var Ps_col}; please apply an appropriate treatment to the missings and rerun {.fn nonlinear_bins}."
-    )
-  }
+  # Check for missingness in the probability of survival data ----
+  validate_complete(input = Ps_check, type = "warning", var_name = "Ps_col")
 
-  # Pull and check the outcome column
-  binary_data <- data |> dplyr::pull({{ outcome_col }})
+  # Pull and check the outcome column ----
+  binary_data <- validate_data_pull(
+    input = data,
+    col = {{ outcome_col }},
+    var_name = "outcome_col",
+    calls = 5
+  )
 
-  # Ensure the column is either logical or numeric
-  if (!is.logical(binary_data) && !is.numeric(binary_data)) {
-    cli::cli_abort(
-      "The {.var outcome_col} must be of type logical (TRUE/FALSE) or numeric (1/0)."
-    )
-  }
+  # Ensure the column is either logical or numeric ----
+  validate_class(
+    input = binary_data,
+    class_type = c("logical", "numeric", "integer"),
+    logic = "or",
+    type = "error",
+    var_name = "outcome_col"
+  )
 
-  # Get unique non-missing values
+  # Get unique non-missing values ----
   non_missing <- stats::na.omit(binary_data)
 
-  # Validate type and values
+  # Provide a warning about missing values ----
+  validate_complete(
+    input = binary_data,
+    type = "warning",
+    var_name = "outcome_col"
+  )
+
+  # Validate type and values ----
   if (is.logical(binary_data)) {
-    # Logical vector: ensure only TRUE/FALSE (no coercion needed)
-    invalid_vals <- setdiff(unique(non_missing), c(TRUE, FALSE))
-    if (length(invalid_vals) > 0) {
-      cli::cli_abort(
-        "The {.var outcome_col} contains invalid logical values: {.val {invalid_vals}}."
-      )
-    }
+    validate_set(
+      input = non_missing,
+      valid_set = c(TRUE, FALSE),
+      type = "error",
+      var_name = "outcome_col"
+    )
   } else if (is.numeric(binary_data)) {
     # Numeric vector: ensure strictly 0 or 1
-    invalid_vals <- setdiff(unique(non_missing), c(0, 1))
-    if (length(invalid_vals) > 0) {
-      cli::cli_abort(
-        "The {.var outcome_col} contains numeric values other than 0 and 1: {.val {invalid_vals}}."
-      )
-    }
-  } else {
-    # Not logical or numeric
-    cli::cli_abort(
-      "The {.var outcome_col} must be either logical (TRUE/FALSE) or numeric (1/0)."
+    validate_set(
+      input = non_missing,
+      valid_set = c(0, 1),
+      type = "error",
+      var_name = "outcome_col"
+    )
+  } else if (is.integer(binary_data)) {
+    # Integer vector: ensure strictly 0 or 1
+    validate_set(
+      input = non_missing,
+      valid_set = c(0L, 1L),
+      type = "error",
+      var_name = "outcome_col"
     )
   }
 
-  # Warn if missing
-  if (any(is.na(binary_data))) {
-    cli::cli_warn(
-      "Missing values detected in {.var outcome_col}; please apply an appropriate treatment to the missings and rerun {.fn nonlinear_bins}."
-    )
+  # Check if all elements in group_vars are strings ----
+  # (i.e., character vectors)
+  if (!is.null(group_vars)) {
+    validate_character_factor(input = group_vars, type = "error")
   }
 
-  # Check if all elements in group_vars are strings (i.e., character vectors)
-  if (!all(sapply(group_vars, is.character))) {
-    cli::cli_abort(c(
-      "All elements in {.var group_vars} must be strings.",
-      "i" = "You passed a {.cls {class(group_vars)}} variable to {.var group_vars}."
-    ))
-  }
+  # Check if all group_vars exist in the data ----
+  validate_names(
+    input = data,
+    check_names = group_vars,
+    type = "error",
+    var_name = "group_vars",
+    null_ok = TRUE
+  )
 
-  # Check if all group_vars exist in the data
-  if (!all(group_vars %in% names(data))) {
-    invalid_vars <- group_vars[!group_vars %in% names(data)]
-    cli::cli_abort(
-      "The following group variable(s) are not valid columns in the data: {paste(invalid_vars, collapse = ', ')}"
-    )
-  }
-
-  # Treat the column-names-as-strings as symbols
+  # Treat the column-names-as-strings as symbols ----
   if (!is.null(group_vars)) {
     group_vars <- rlang::syms(group_vars)
   }
 
-  # Select and sort the column
-  survival_data <- data |> dplyr::pull({{ Ps_col }}) |> sort()
-  total <- length(survival_data)
+  # Select and sort the Ps_col column ----
+  # Assumes that the user has dealt with missing values, if they exist
+  survival_data <- Ps_check |> sort()
 
-  # length of non-missing `Ps_col` must be >= 2
-  if (na.omit(total) < 2) {
-    cli::cli_abort(c(
-      "At least two non-missing values are required in {.var Ps_col} to compute survival probability intervals.",
-      "v" = "Ensure {.var Ps_col} contains at least two valid, non-missing numeric entries."
-    ))
-  }
+  # length of non-missing `Ps_col` must be >= 2 ----
+  # It is possible for this check to succeed if missings exist
+  validate_length(
+    input = survival_data,
+    min_length = 2,
+    max_length = Inf,
+    type = "error",
+    na_ok = TRUE,
+    null_ok = TRUE,
+    var_name = "Ps_col"
+  )
 
-  # Step 1: Find indices for level thresholds
+  # Step 1: Find indices for level thresholds ----
   loc_9A <- which(survival_data > threshold_1) # Everything above 0.9 or other threshold
   loc_9B <- which(survival_data > threshold_2) # Everything above 0.99 or other threshold
   loc_9C <- which(survival_data > threshold_1 & survival_data <= threshold_2) # Between 0.9 and 0.99 or other thresholds
 
-  # Step 2: Define step sizes based on the data
+  # Step 2: Define step sizes based on the data ----
   step1 <- round(suppressWarnings(min(loc_9A, na.rm = TRUE)) / divisor1)
   step2 <- round(length(loc_9C) / divisor2)
 
-  # Step 3: Define intervals
+  # Step 3: Define intervals ----
   # Check that loc_9A and loc_9B are finite before using them in seq()
   if (
     suppressWarnings(
@@ -397,12 +411,12 @@ nonlinear_bins <- function(
     )
   }
 
-  # Generate intervals based on these positions
+  # Generate intervals based on these positions ----
   intervals <- unique(survival_data[len])
 
-  # Step 4: Bin statistics
+  # Step 4: Bin statistics ----
 
-  # Apply binning to each group separately
+  # Apply binning to each group separately ----
   data <- data |>
     dplyr::mutate(
       bin_number = .bincode(
@@ -414,65 +428,88 @@ nonlinear_bins <- function(
       bin_end = intervals[bin_number + 1] # End of the bin
     )
 
-  # Optionally group data by dynamic group_vars
+  # Optionally group data by dynamic group_vars ----
   # Or run the bin statistics on the whole dataset
   if (!is.null(group_vars)) {
+    # Group the data by the specified group_vars and bin-related columns
     grouped_stats <- data |>
       dplyr::group_by(!!!group_vars, bin_number, bin_start, bin_end) |>
       dplyr::summarize(
+        # Calculate the mean of the probability of survival (Ps_col)
         mean = mean({{ Ps_col }}, na.rm = TRUE),
+        # Calculate the standard deviation of the probability of survival (Ps_col)
         sd = stats::sd({{ Ps_col }}, na.rm = TRUE),
+        # Sum the predicted survivors based on the probability of survival (Ps_col)
         Pred_Survivors_b = sum({{ Ps_col }}, na.rm = TRUE),
+        # Sum the predicted deaths based on the probability of survival (Ps_col)
         Pred_Deaths_b = sum(1 - {{ Ps_col }}, na.rm = TRUE),
+        # Calculate the anticipated survival rate
         AntiS_b = dplyr::if_else(
           dplyr::n() > 0,
           Pred_Survivors_b / dplyr::n(),
           NA_real_
         ),
+        # Calculate the anticipated mortality rate
         AntiM_b = dplyr::if_else(
           dplyr::n() > 0,
           Pred_Deaths_b / dplyr::n(),
           NA_real_
         ),
+        # Count the number of alive patients
         alive = sum({{ outcome_col }} == 1, na.rm = TRUE),
+        # Count the number of dead patients
         dead = sum({{ outcome_col }} == 0, na.rm = TRUE),
+        # Count the total number of observations
         count = dplyr::n(),
         .groups = "drop"
       ) |>
       dplyr::ungroup() |>
+      # Group the data again by the specified group_vars
       dplyr::group_by(!!!group_vars) |>
       dplyr::mutate(
+        # Calculate the percentage of each group
         percent = count / sum(count, na.rm = TRUE)
       ) |>
       dplyr::ungroup()
   } else {
+    # Group the data by bin-related columns only
     grouped_stats <- data |>
       dplyr::group_by(bin_number, bin_start, bin_end) |>
       dplyr::summarize(
+        # Calculate the mean of the probability of survival (Ps_col)
         mean = mean({{ Ps_col }}, na.rm = TRUE),
+        # Calculate the standard deviation of the probability of survival (Ps_col)
         sd = stats::sd({{ Ps_col }}, na.rm = TRUE),
+        # Sum the predicted survivors based on the probability of survival (Ps_col)
         Pred_Survivors_b = sum({{ Ps_col }}, na.rm = TRUE),
+        # Sum the predicted deaths based on the probability of survival (Ps_col)
         Pred_Deaths_b = sum(1 - {{ Ps_col }}, na.rm = TRUE),
+        # Calculate the anticipated survival; rate
         AntiS_b = dplyr::if_else(
           dplyr::n() > 0,
           Pred_Survivors_b / dplyr::n(),
           NA_real_
         ),
+        # Calculate the anticipated mortality rate
         AntiM_b = dplyr::if_else(
           dplyr::n() > 0,
           Pred_Deaths_b / dplyr::n(),
           NA_real_
         ),
+        # Count the number of alive patients
         alive = sum({{ outcome_col }} == 1, na.rm = TRUE),
+        # Count the number of dead patients
         dead = sum({{ outcome_col }} == 0, na.rm = TRUE),
+        # Count the total number of observations
         count = dplyr::n(),
         .groups = "drop"
       ) |>
       dplyr::mutate(
+        # Calculate the percentage of each group
         percent = count / sum(count, na.rm = TRUE)
       )
   }
 
-  # Return a list with intervals and the bin statistics
+  # Return a list with intervals and the bin statistics ----
   return(list(intervals = intervals, bin_stats = grouped_stats))
 }
