@@ -26,26 +26,35 @@
 #' @author Nicolas Foss, Ed.D., MS
 #'
 pretty_percent <- function(variable, n_decimal = 1) {
-  # Ensure the input is numeric
-  if (!is.numeric(variable)) {
-    cli::cli_abort(
-      "The `variable` argument must be numeric. You supplied {.cls {class(variable)}}."
-    )
-  }
+  # Save the current options settings to restore them later ----
+  old <- options()
 
-  # Ensure n_decimal is valid
-  if (!is.numeric(n_decimal) || n_decimal < 0) {
-    cli::cli_abort(
-      "The `n_decimal` argument must be a positive numeric value. You supplied {.val {n_decimal}}."
-    )
-  }
+  # Ensure that the original options are restored when the function exits, ----
+  # even if an error occurs
+  on.exit(options(old))
 
-  # Convert to percentage with specified decimal places
-  formatted_percent <- paste0(round(variable * 100, digits = n_decimal), "%")
+  # Set the 'scipen' option to a high value to prevent scientific notation ----
+  # in the output. This ensures that large numbers are displayed in their
+  # full numeric form rather than in scientific notation.
+  options(scipen = 9999)
 
-  # Remove trailing zeros after decimal point and the period if unnecessary
+  # Ensure the input is numeric ----
+  validate_numeric(input = variable, min = -1, max = 1, type = "error")
+
+  # Ensure n_decimal is valid ----
+  validate_numeric(input = n_decimal, min = 0, type = "error")
+
+  # Format percentages with NA handling ----
+  formatted_percent <- ifelse(
+    is.na(variable),
+    NA_character_,
+    paste0(round(variable * 100, digits = n_decimal), "%")
+  )
+
+  # Remove trailing zeros after decimal point and the period if unnecessary ----
   formatted_percent <- sub("(\\.\\d*?)0+%$", "\\1%", formatted_percent) # Remove trailing zeros
   formatted_percent <- sub("\\.%$", "%", formatted_percent) # Remove ending "."
 
+  # Complete the transformation ----
   return(formatted_percent)
 }
