@@ -74,59 +74,54 @@
 #' result
 #'
 probability_of_survival <- function(trauma_type, age, rts, iss) {
-  # Check trauma_type
-  if (!is.character(trauma_type) && !is.factor(trauma_type)) {
-    cli::cli_abort(
-      "The {.var trauma_type} column must be of type {.cls character} or {.cls factor}."
-    )
-  }
+  # Ensure trauma_type is character or factor
+  # Set up trauma_type validity checks ----
+  validate_character_factor(input = trauma_type, type = "e")
 
-  # Check for valid values in trauma_type, ignoring NA
-  valid_trauma_types <- c("Blunt", "Penetrating", "Burn")
-  if (
-    !all(unique(trauma_type[!is.na(trauma_type)]) %in% c(valid_trauma_types))
-  ) {
-    cli::cli_warn(
-      "The {.var trauma_type} column contains values other than 'Blunt', 'Penetrating', or 'Burn'."
-    )
-  }
+  # Vector of valid trauma_type(s) ----
+  valid_trauma_types <- c("Blunt", "Penetrating")
 
-  # Warn about 'Burn' and missing values
-  if (any(trauma_type %in% "Burn", na.rm = TRUE) | any(is.na(trauma_type))) {
-    cli::cli_warn(
-      "The {.var trauma_type} column contains missing and/or 'Burn' values. These records will not receive a probability of survival calculation."
-    )
-  }
+  # Check for valid values in trauma_type, ignoring NA ----
+  validate_set(
+    input = trauma_type,
+    valid_set = valid_trauma_types,
+    type = "w"
+  )
 
-  # Check age
-  if (any(age < 0, na.rm = TRUE)) {
-    cli::cli_warn(c(
-      "Negative values detected in the {.var age} column.",
-      "i" = "{.var age} must be a non-negative {.cls numeric} value."
-    ))
-  }
+  # Check age ----
+  validate_numeric(
+    input = age,
+    min = 0,
+    type = "warning",
+    na_ok = TRUE,
+    null_ok = TRUE
+  )
 
-  # Check rts
-  if (any(rts < 0 | rts > 7.84, na.rm = TRUE)) {
-    cli::cli_warn(c(
-      "Negative values detected in the {.var rts} column.",
-      "i" = "{.var rts} must be a {.cls numeric} value between 0 and 7.84."
-    ))
-  }
+  # Check rts ----
+  validate_numeric(
+    input = rts,
+    min = 0,
+    max = 7.8408,
+    type = "warning",
+    na_ok = TRUE,
+    null_ok = TRUE
+  )
 
-  # Check iss
-  if (any(iss < 0 | iss > 75, na.rm = TRUE)) {
-    cli::cli_warn(c(
-      "{.var iss} values less than 0 or greater than 75 were detected.",
-      "i" = "{.var iss} must be a {.cls numeric} value between 0 and 75."
-    ))
-  }
+  # Check iss ----
+  validate_numeric(
+    input = iss,
+    min = 0,
+    max = 75,
+    type = "warning",
+    na_ok = TRUE,
+    null_ok = TRUE
+  )
 
-  # Assign age category
+  # Assign age category ----
   # Age points are assigned as 0 if age is less than 55, otherwise 1
   age_points <- ifelse(age < 55, 0, 1)
 
-  # Assign coefficients for b0
+  # Assign coefficients for b0 ----
   # Coefficient b0 is assigned based on trauma type
   b0 <- ifelse(
     trauma_type == "Blunt",
@@ -138,7 +133,7 @@ probability_of_survival <- function(trauma_type, age, rts, iss) {
     )
   )
 
-  # Assign coefficients for b1
+  # Assign coefficients for b1 ----
   # Coefficient b1 is assigned based on trauma type
   b1 <- ifelse(
     trauma_type == "Blunt",
@@ -150,7 +145,7 @@ probability_of_survival <- function(trauma_type, age, rts, iss) {
     )
   )
 
-  # Assign coefficients for b2
+  # Assign coefficients for b2 ----
   # Coefficient b2 is assigned based on trauma type
   b2 <- ifelse(
     trauma_type == "Blunt",
@@ -162,7 +157,7 @@ probability_of_survival <- function(trauma_type, age, rts, iss) {
     )
   )
 
-  # Assign coefficients for b3
+  # Assign coefficients for b3 ----
   # Coefficient b3 is assigned based on trauma type
   b3 <- ifelse(
     trauma_type == "Blunt",
@@ -174,16 +169,16 @@ probability_of_survival <- function(trauma_type, age, rts, iss) {
     )
   )
 
-  # Perform calculation
+  # Perform calculation ----
   # Calculate the logit value using the assigned coefficients and input
   # variables
   b <- b0 + (b1 * rts) + (b2 * iss) + (b3 * age_points)
 
-  # Predicted probability of survival
+  # Predicted probability of survival ----
   # Calculate the probability of survival using the logistic function
   survival_calc <- 1 / (1 + exp(-b))
 
-  # End function
+  # End function ----
   # Return the calculated probability of survival
   return(survival_calc)
 }
